<?php
/**
* The template for displaying comments
*
* This is the template that displays the area of the page that contains both the current comments
* and the comment form.
*
* @link https://developer.wordpress.org/themes/basics/template-hierarchy/
*
* @package MagPal WordPress Theme
* @copyright Copyright (C) 2025 ThemesDNA
* @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 or later
* @author ThemesDNA <themesdna@gmail.com>
*/

/*
 * If the current post is protected by a password and
 * the visitor has not yet entered the password we will
 * return early without loading the comments.
 */
if ( post_password_required() ) {
    return;
}
?>

<div id="comments" class="comments-area">

    <?php
    // Start editing here.
    if ( have_comments() ) :
    ?>
        <h2 class="comments-title">
            <?php
            $magpal_comment_count = get_comments_number();
            if ( 1 === $magpal_comment_count ) {
                printf(
                    /* translators: 1: Post title */
                    esc_html__( 'One thought on &ldquo;%1$s&rdquo;', 'magpal' ),
                    '<span>' . wp_kses_post( get_the_title() ) . '</span>' /* phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped */
                );
            } else {
                printf(
                    /* translators: 1: Comment count, 2: Post title */
                    esc_html(
                        _nx(
                            '%1$s thought on &ldquo;%2$s&rdquo;',
                            '%1$s thoughts on &ldquo;%2$s&rdquo;',
                            $magpal_comment_count,
                            'comments title',
                            'magpal'
                        )
                    ),
                    number_format_i18n( $magpal_comment_count ), /* phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped */
                    '<span>' . wp_kses_post( get_the_title() ) . '</span>' /* phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped */
                );
            }
            ?>
        </h2><!-- .comments-title -->

        <?php the_comments_navigation(); ?>

        <ol class="comment-list">
            <?php
                wp_list_comments([
                    'style'       => 'ol',
                    'short_ping'  => true,
                    'avatar_size' => 64,
                ]);
            ?>
        </ol><!-- .comment-list -->

        <?php the_comments_navigation(); ?>

        <?php if ( ! comments_open() ) : ?>
            <p class="no-comments"><?php esc_html_e( 'Comments are closed.', 'magpal' ); ?></p>
        <?php endif; ?>

    <?php endif; // End have_comments() check. ?>

    <?php comment_form(); ?>

</div><!-- #comments -->